<?php
/**
 * Hooks for site origin.
 *
 * This file contains hook functions attached to core hooks of site origin bundle.
 *
 * @package Restaurantz
 */

if ( ! function_exists( 'restaurantz_customize_features_widget_fields' ) ) :

	/**
	 * Customize features widget fields.
	 *
	 * @since 1.0.0
	 *
	 * @param array             $form_options Form options.
	 * @param SiteOrigin_Widget $widget Widget instance.
	 * @return array Modified form options.
	 */
	function restaurantz_customize_features_widget_fields( $form_options, $widget ) {

		// Change defaults.
		$form_options['features']['fields']['container_color']['default'] = '#dd9933';
		$form_options['features']['fields']['icon_color']['default'] = '#dd9933';
		$form_options['features']['fields']['icon']['default'] = 'fontawesome-star';
		$form_options['features']['fields']['container_color']['default'] = '#dd9933';
		$form_options['container_shape']['default'] = '';
		$form_options['icon_size']['default'] = '60px';
		$form_options['per_row']['default'] = 4;

		return $form_options;

	}

endif;

add_filter( 'siteorigin_widgets_form_options_sow-features', 'restaurantz_customize_features_widget_fields', 10, 2 );

if ( ! function_exists( 'restaurantz_add_tab_in_builer_widgets_panel' ) ) :

	/**
	 * Add tab in builder widgets section.
	 *
	 * @since 1.0.0
	 *
	 * @param array $tabs Tabs.
	 * @return array Modified tabs.
	 */
	function restaurantz_add_tab_in_builer_widgets_panel( $tabs ) {
		$tabs['restaurantz-pro'] = array(
			'title'  => __( 'Restaurantz Widgets', 'restaurantz-pro' ),
			'filter' => array(
				'groups' => array( 'restaurantz-pro' ),
			),
		);
		return $tabs;
	}

endif;

add_filter( 'siteorigin_panels_widget_dialog_tabs', 'restaurantz_add_tab_in_builer_widgets_panel' );

if ( ! function_exists( 'restaurantz_group_theme_widgets_in_builder' ) ) :

	/**
	 * Grouping theme widgets in builder.
	 *
	 * @since 1.0.0
	 *
	 * @param array $widgets Widgets array.
	 * @return array Modified widgets array.
	 */
	function restaurantz_group_theme_widgets_in_builder( $widgets ) {

		if ( isset( $GLOBALS['wp_widget_factory'] ) && ! empty( $GLOBALS['wp_widget_factory']->widgets ) ) {
			$all_widgets = array_keys( $GLOBALS['wp_widget_factory']->widgets );
			foreach ( $all_widgets as $widget ) {
				if ( false !== strpos( $widget, 'Restaurantz_' ) ) {
					$widgets[ $widget ]['groups'] = array( 'restaurantz-pro' );
					$widgets[ $widget ]['icon']   = 'dashicons dashicons-awards';
				}
			}
		}
		return $widgets;

	}
endif;

add_filter( 'siteorigin_panels_widgets', 'restaurantz_group_theme_widgets_in_builder' );


if ( ! function_exists( 'restaurantz_panels_row_style_attributes' ) ) :

	/**
	 * Add custom attributes in row.
	 *
	 * @since 1.0.0
	 *
	 * @param array $attr Attributes.
	 * @param array $style Widget style.
	 * @return array Modified attributes.
	 */
	function restaurantz_panels_row_style_attributes( $attr, $style ) {

		if ( isset( $style['row_stretch'] ) && 'full' === $style['row_stretch'] ) {
			$attr['class'][] = 'panel-row-style-full-width';
		}
		if ( isset( $style['row_stretch'] ) && 'full-stretched' === $style['row_stretch'] ) {
			$attr['class'][] = 'panel-row-style-full-stretched';
		}
		return $attr;

	}

endif;

add_filter( 'siteorigin_panels_row_style_attributes', 'restaurantz_panels_row_style_attributes', 10, 2 );


if ( ! function_exists( 'restaurantz_customize_builder_widget_style_fields' ) ) :

	/**
	 * Customize widget style fields.
	 *
	 * @since 1.0.0
	 *
	 * @param array $fields Style fields.
	 * @param int   $post_id Post ID.
	 * @param array $args Arguments.
	 * @return array Modified fields.
	 */
	function restaurantz_customize_builder_widget_style_fields( $fields, $post_id, $args ) {

		$fields['animation_effect'] = array(
			'name'        => __( 'Effect', 'restaurantz-pro' ),
			'description' => __( 'Choose an animation style.', 'restaurantz-pro' ),
			'type'        => 'select',
			'group'       => 'animation',
			'priority'    => 1,
			'options'     => restaurantz_get_wow_animation_effects_options(),
		);
		$fields['animation_duration'] = array(
			'name'        => __( 'Duration', 'restaurantz-pro' ),
			'description' => __( 'Change the animation duration.', 'restaurantz-pro' ),
			'type'        => 'select',
			'group'       => 'animation',
			'priority'    => 2,
			'options'     => restaurantz_get_wow_animation_duration_options(),
		);
		$fields['animation_delay'] = array(
			'name'        => __( 'Delay', 'restaurantz-pro' ),
			'description' => __( 'Delay before the animation starts.', 'restaurantz-pro' ),
			'type'        => 'select',
			'group'       => 'animation',
			'priority'    => 3,
			'options'     => restaurantz_get_wow_animation_delay_options(),
		);
		$fields['animation_offset'] = array(
			'name'        => __( 'Offset', 'restaurantz-pro' ),
			'description' => __( 'Distance in pixel to start the animation.', 'restaurantz-pro' ),
			'type'        => 'text',
			'group'       => 'animation',
			'priority'    => 4,
		);
		$fields['animation_iteration'] = array(
			'name'        => __( 'Iteration', 'restaurantz-pro' ),
			'description' => __( 'Number of times the animation is repeated.', 'restaurantz-pro' ),
			'type'        => 'select',
			'group'       => 'animation',
			'priority'    => 5,
			'options'     => restaurantz_get_wow_animation_iteration_options(),
		);

		return $fields;

	}

endif;

add_filter( 'siteorigin_panels_widget_style_fields', 'restaurantz_customize_builder_widget_style_fields', 10, 3 );

if ( ! function_exists( 'restaurantz_customize_builder_widget_style_groups' ) ) :

	/**
	 * Customize widget style groups.
	 *
	 * @since 1.0.0
	 *
	 * @param array $groups Style groups.
	 * @param int   $post_id Post ID.
	 * @param array $args Arguments.
	 * @return array Modified groups.
	 */
	function restaurantz_customize_builder_widget_style_groups( $groups, $post_id, $args ) {

		$groups['animation'] = array(
			'name'     => __( 'Animation', 'restaurantz-pro' ),
			'priority' => 20,
		);

		return $groups;

	}

endif;

add_filter( 'siteorigin_panels_widget_style_groups', 'restaurantz_customize_builder_widget_style_groups', 10, 3 );

if ( ! function_exists( 'restaurantz_customize_builder_widget_style_attributes' ) ) :

	/**
	 * Customize widget style sttributes.
	 *
	 * @since 1.0.0
	 *
	 * @param array $attr Attributes array.
	 * @param array $style Style array.
	 * @return array Modified attributes array.
	 */
	function restaurantz_customize_builder_widget_style_attributes( $attr, $style ) {

		// Animation effect class.
		if ( isset( $style['animation_effect'] ) && 'no-animation' !== $style['animation_effect'] ) {
			$attr['class'][] = 'wow';
			$attr['class'][] = esc_attr( $style['animation_effect'] );
		}

		// Animation duration.
		if ( isset( $style['animation_duration'] ) && absint( $style['animation_duration'] ) > 0 ) {
			$attr['data-wow-duration'] = absint( $style['animation_duration'] ) . 's';
		}

		// Animation delay.
		if ( isset( $style['animation_delay'] ) && absint( $style['animation_delay'] ) > 0 ) {
			$attr['data-wow-delay'] = absint( $style['animation_delay'] ) . 's';
		}

		// Offset position.
		if ( isset( $style['animation_offset'] ) && absint( $style['animation_offset'] ) > 0 ) {
			$attr['data-wow-offset'] = absint( $style['animation_offset'] );
		}

		// Animation iteration.
		if ( isset( $style['animation_iteration'] ) && absint( $style['animation_iteration'] ) > 0 ) {
			$attr['data-wow-iteration'] = absint( $style['animation_iteration'] );
		}

		return $attr;

	}

endif;

add_filter( 'siteorigin_panels_widget_style_attributes', 'restaurantz_customize_builder_widget_style_attributes', 10, 2 );


if ( ! function_exists( 'restaurantz_customize_so_widgets_status' ) ) :

	/**
	 * Customize to make widgets active.
	 *
	 * @since 1.0.0
	 *
	 * @param array $active Array of widgets.
	 * @return array Modified array.
	 */
	function restaurantz_customize_so_widgets_status( $active ) {

		$active['so-features-widget']    = true;
		$active['features']              = true;

		$active['so-slider-widget']      = true;
		$active['slider']                = true;

		$active['so-google-map-widget']  = true;
		$active['google-map']            = true;

		$active['so-image-widget']       = true;
		$active['image']                 = true;

		$active['so-cta-widget']         = true;
		$active['cta']                   = true;

		$active['so-contact-widget']     = true;
		$active['contact']               = true;

		$active['so-testimonial-widget'] = true;
		$active['testimonial']           = true;

		$active['so-hero-widget']        = true;
		$active['hero']                  = true;

		return $active;

	}

endif;

add_filter( 'siteorigin_widgets_active_widgets', 'restaurantz_customize_so_widgets_status' );
