<?php
/**
 * Template file.
 *
 * @package Restaurantz
 */

?>
<?php if ( ! empty( $instance['title'] ) ) : ?>
	<?php echo $args['before_title'] . esc_html( $instance['title'] ) . $args['after_title']; ?>
<?php endif; ?>
<?php if ( ! empty( $instance['sub_title'] ) ) : ?>
	<h4 class="widget-sub-title"><?php echo esc_html( $instance['sub_title'] ); ?></h4>
<?php endif; ?>

<?php if ( class_exists( 'EM_Events' ) ) :  ?>
	<?php
	// Get query args.
	$events_args = $this->get_event_query_args( $instance );
	$events = EM_Events::get( $events_args );
	?>

	<?php if ( ! empty( $events ) ) : ?>

		<?php
		$event = $events[0];
		$location_args = array(
			'location_id' => $event->location_id,
			);
		$locations = EM_Locations::get( $location_args );
		?>

		<div class="featured-event-widget-main-wrapper">
			<div class="event-highlight-section">
				<div class="featured-event-image">
					<?php
					$image_attributes = '';
					$image_attributes = wp_get_attachment_image_src( get_post_thumbnail_id( $event->post_id ), 'large' );
					?>
					<?php if ( $image_attributes ) : ?>
						<img src="<?php echo esc_url( $image_attributes[0] ); ?>" width="<?php echo esc_attr( $image_attributes[1] ); ?>" height="<?php echo esc_attr( $image_attributes[2] ); ?>" />
					<?php else : ?>
						<img src="<?php echo get_template_directory_uri(); ?>/images/no-image-event.png" alt="" />
					<?php endif; ?>
				</div><!-- .featured-event-image -->
				<div class="event-meta">
					<?php if ( ! empty( $event->start ) ) : ?>
						<?php
						$event_date     = $event->start;
						$day_in_digit   = date( 'd', $event_date );
						$month          = date( 'M', $event_date );
						$year           = date( 'Y', $event_date );
						$day_in_letters = date( 'l', $event_date );
						?>
						<span class="event-date"><?php echo esc_attr( $day_in_digit ); ?></span><!-- .event-date -->
						<div class="event-dym-wrap">
							<span class="event-month"><?php echo esc_attr( $month ); ?></span>
							<span class="event-year-months"><?php echo esc_attr( $year ); ?></span>
							<div class="event-day"><?php echo esc_attr( $day_in_letters ); ?></div>
						</div><!-- .event-dym-wrap -->
						<span class="event-start-time">
							<?php
							if ( 1 === absint( $event->event_all_day ) ) {
								echo __( 'All Day', 'restaurantz-pro' );
							} else {
								echo date( 'H:i', strtotime( $event->event_start_time ) );
								echo ' - ' . date( 'H:i', strtotime( $event->event_end_time ) );
							}
							?>
							<?php  ?>
						</span><!-- .event-start-time -->
					<?php endif; ?>
				</div><!-- .event-meta -->
			</div><!-- .event-highlight-section -->
			<div class="event-details-section">
				<div class="event-meta">
					<h4 class="event-name">
						<a href="<?php echo esc_url( get_permalink( $event->post_id ) ); ?>"><?php echo esc_html( $event->event_name ); ?></a>
					</h4>
					<span class="event-start-date">
						<?php
						echo date( 'd/m/Y', strtotime( $event->event_start_date ) );
						if ( $event->event_end_date !== $event->event_start_date ) {
							echo ' - ' . date( 'd/m/Y', strtotime( $event->event_end_date ) );
						}
						?>
					</span><!-- .event-start-date -->

					<?php if ( ! empty( $locations ) ) : ?>
						<?php $location = $locations[0]; ?>
						<h4 class="event-location">
							<?php
							if ( $location->location_address ) {
								echo esc_html( $location->location_address ) . ', ';
							}
							if ( $location->location_town ) {
								echo esc_html( $location->location_town ) . ', ';
							}
							$country_name = $this->get_country_from_country_code( $location->location_country );
							if ( $country_name ) {
								echo esc_html( $country_name );
							}
							?>
						</h4>
					<?php endif; ?>

				</div><!-- .event-meta -->
				<div class="event-content">
					<?php
					$event_excerpt = restaurantz_the_excerpt( 50, $event );
					echo wp_kses_post( wpautop( $event_excerpt ) );
					?>
				</div><!-- .event-content -->

				<?php $terms = get_the_terms( $event->post_id, 'event-categories' ); ?>

				<?php if ( $terms && ! is_wp_error( $terms ) ) : ?>
					<span class="event-categories">
						<?php _e( 'Categories:','restaurantz-pro' ); ?>
						<?php
						$prefix     = '';
						$terms_html = '';
						foreach ( $terms as $term ) {
							$terms_html .= $prefix . '<a href="' . get_term_link( $term ) . '">' . esc_html( $term->name ) . '</a>';
							$prefix = ', ';
						}
						echo $terms_html;
						?>
					</span><!-- .event-categories -->
				<?php endif; ?>

				<?php $terms = get_the_terms( $event->post_id, 'event-tags' ); ?>

				<?php if ( $terms && ! is_wp_error( $terms ) ) : ?>
					<span class="event-tags">
						<?php _e( 'Tags:','restaurantz-pro' ); ?>
						<?php
						$prefix     = '';
						$terms_html = '';
						foreach ( $terms as $term ) {
							$terms_html .= $prefix . '<a href="' . get_term_link( $term ) . '">' . esc_html( $term->name ) . '</a>';
							$prefix = ', ';
						}
						echo $terms_html;
						?>
					</span><!-- .event-categories -->
				<?php endif; ?>

			</div><!-- .event-details-section -->

		</div><!-- .featured-event-widget-main-wrapper -->

	<?php else : ?>

		<p><?php _e( 'No Events Found', 'restaurantz-pro' ); ?></p>

	<?php endif; ?>

<?php else : ?>

	<?php if ( current_user_can( 'manage_options' ) ) : ?>

		<p><?php _e( 'Events Manager plugin is not activated.', 'restaurantz-pro' ); ?>

	<?php else : ?>

		<p><?php _e( 'No Events Found', 'restaurantz-pro' ); ?>

	<?php endif; ?>

<?php endif;
