<?php

class Restaurantz_Special_Dishes_Widget extends SiteOrigin_Widget {

	function __construct() {

		parent::__construct(
			'restaurantz-special-dishes',
			__( 'Restaurantz: Special Dishes', 'restaurantz-pro' ),
			array(
				'description' => __( 'Display Special Dishes.', 'restaurantz-pro' ),
			),
			array(),
			array(
				'title' => array(
					'type'  => 'text',
					'label' => __( 'Title', 'restaurantz-pro' ),
				),
				'sub_title' => array(
					'type'  => 'text',
					'label' => __( 'Subtitle', 'restaurantz-pro' ),
				),
				'dishes_post_id' => array(
					'type'        => 'posts',
					'label'       => __( 'Select Dishes', 'restaurantz-pro' ),
					'description' => sprintf( __( 'Choose %1$sPost Type%2$s as %3$sMenu Items%4$s while building query to select dishes.', 'restaurantz-pro' ), '<strong>', '</strong>', '<strong>', '</strong>' ),
				),
				'dishes_custom_ids' => array(
					'type'        => 'text',
					'label'       => __( 'Menu IDs', 'restaurantz-pro' ),
					'description' => __( 'Enter Menu IDs separated by comma. These IDs will be used if no Dishes are selected in above field.', 'restaurantz-pro' ),
				),
				'settings' => array(
					'type'   => 'section',
					'label'  => __( 'Settings', 'restaurantz-pro' ),
					'fields' => array(
						'per_row' => array(
							'type'    => 'select',
							'label'   => __( 'Dishes Per Row', 'restaurantz-pro' ),
							'default' => 4,
							'options' => array(
								'1' => 1,
								'2' => 2,
								'3' => 3,
								'4' => 4,
							),
						),
						'featured_image' => array(
							'type'    => 'select',
							'label'   => __( 'Image Size', 'restaurantz-pro' ),
							'default' => 'restaurantz-food-thumb',
							'options' => restaurantz_get_image_sizes_options(),
						),
						'excerpt_settings' => array(
							'type'   => 'section',
							'label'  => __( 'Excerpt Settings', 'restaurantz-pro' ),
							'hide'   => true,
							'fields' => array(
								'excerpt_length' => array(
									'type'        => 'number',
									'label'       => __( 'Excerpt Length', 'restaurantz-pro' ),
									'description' => __( 'in words', 'restaurantz-pro' ),
									'default'     => 20,
								),
								'disable_excerpt' => array(
									'type'  => 'checkbox',
									'label' => __( 'Disable Excerpt', 'restaurantz-pro' ),
								),
							),
						),

					),
				),
				'settings_color' => array(
						'type'   => 'section',
						'label'  => __( 'Color Settings', 'restaurantz-pro' ),
						'hide'   => true,
						'fields' => array(
							'color_widget_title' => array(
								'type'    => 'color',
								'label'   => __( 'Widget Title Color', 'restaurantz-pro' ),
								'default' => '#562c19',
							),
							'color_widget_sub_title' => array(
								'type'    => 'color',
								'label'   => __( 'Widget Subtitle Color', 'restaurantz-pro' ),
								'default' => '#313131',
							),
							'color_dish_title' => array(
								'type'    => 'color',
								'label'   => __( 'Dish Title Color', 'restaurantz-pro' ),
								'default' => '#fef9f5',
							),
							'color_dish_title_background' => array(
								'type'    => 'color',
								'label'   => __( 'Dish Title Background Color', 'restaurantz-pro' ),
								'default' => '#ffffff',
							),
							'color_excerpt_background' => array(
								'type'    => 'color',
								'label'   => __( 'Excerpt Background Color', 'restaurantz-pro' ),
								'default' => '#ffffff',
							),
							'color_excerpt_text' => array(
								'type'    => 'color',
								'label'   => __( 'Excerpt Text Color', 'restaurantz-pro' ),
								'default' => '#313131',
							),
							'color_meta_background' => array(
								'type'    => 'color',
								'label'   => __( 'Meta Background Color', 'restaurantz-pro' ),
								'default' => '#7f390a',
							),
							'color_meta_text' => array(
								'type'    => 'color',
								'label'   => __( 'Meta Text Color', 'restaurantz-pro' ),
								'default' => '#ffffff',
							),
		    			),
				),
			),
			plugin_dir_path( __FILE__ )
		);
	}

	function get_valid_menu_ids( $instance ) {

		$posts_selector = $instance['dishes_post_id'];
		$raw_select_ids = siteorigin_widget_post_selector_process_query( $posts_selector );
		$custom_ids     = $instance['dishes_custom_ids'];

		$valid_select_ids = array();
		$select_ids       = array();
		$output           = array();

		if ( isset( $raw_select_ids['post_type'] ) && 'nova_menu_item' == $raw_select_ids['post_type'] ) {
			$all_posts = get_posts( $raw_select_ids );
			$valid_select_ids = wp_list_pluck( $all_posts, 'ID' );
		}

		if ( ! empty( $valid_select_ids ) ) {
			$output = $valid_select_ids;
		}

		if ( empty( $output ) ) {

			// No IDs from select box; try from custom text input.
			$custom_ids = sanitize_text_field( $custom_ids );
			$exploded = explode( ',', $custom_ids );
			$temp_ids = $exploded;
			$valid_custom_ids = array();

			if ( ! empty( $temp_ids ) ) {
				for ( $i = 0; $i < count( $temp_ids ); $i++ ) {
					if ( 'nova_menu_item' === get_post_type( $temp_ids[ $i ] ) ) {
						$valid_custom_ids[] = $temp_ids[ $i ];
					}
				}
			}

			if ( ! empty( $valid_custom_ids ) ) {
				$output = $valid_custom_ids;
			}
		} // End if output.

		return $output;

	}

	function get_template_name( $instance ) {
		return 'default';
	}

	function get_style_name( $instance ) {
		return 'default';
	}

	function get_less_variables( $instance ) {

		$less_vars = array();
		if ( ! empty( $instance['settings_color']['color_widget_title'] ) ) {
			$less_vars['color_widget_title'] = $instance['settings_color']['color_widget_title'];
		}
		if ( ! empty( $instance['settings_color']['color_widget_sub_title'] ) ) {
			$less_vars['color_widget_sub_title'] = $instance['settings_color']['color_widget_sub_title'];
		}
		if ( ! empty( $instance['settings_color']['color_dish_title'] ) ) {
			$less_vars['color_dish_title'] = $instance['settings_color']['color_dish_title'];
		}
		if ( ! empty( $instance['settings_color']['color_dish_title_background'] ) ) {
			$less_vars['color_dish_title_background'] = $instance['settings_color']['color_dish_title_background'];
		}
		if ( ! empty( $instance['settings_color']['color_excerpt_background'] ) ) {
			$less_vars['color_excerpt_background'] = $instance['settings_color']['color_excerpt_background'];
		}
		if ( ! empty( $instance['settings_color']['color_excerpt_text'] ) ) {
			$less_vars['color_excerpt_text'] = $instance['settings_color']['color_excerpt_text'];
		}
		if ( ! empty( $instance['settings_color']['color_meta_background'] ) ) {
			$less_vars['color_meta_background'] = $instance['settings_color']['color_meta_background'];
		}
		if ( ! empty( $instance['settings_color']['color_meta_text'] ) ) {
			$less_vars['color_meta_text'] = $instance['settings_color']['color_meta_text'];
		}
		return $less_vars;

	}
}

siteorigin_widget_register( 'restaurantz-special-dishes', __FILE__, 'Restaurantz_Special_Dishes_Widget' );
